# comment out if not pre release
#define prel a7

# rel for bumping
%define rel 4

Name:           mopidy
Version:        3.0.2
Release:        %mkrel %{?prel:0.%prel.}%{rel}
Group:          Sound/Players
Summary:        Music server with MPD and Spotify support
License:        ASL 2.0
URL:            https://www.mopidy.com/
Source0:        https://github.com/mopidy/mopidy/archive/v%{version}%{?prel}/%{name}-%{version}%{?prel}.tar.gz
Patch1:         0001-Fix-sphinx-extlinks-warning.patch
BuildArch:      noarch
BuildRequires:  python3dist(setuptools)
# for docs
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(pykka)
Requires:       gstreamer1.0-python
Requires:       gstreamer1.0-plugins-base
Requires:       gstreamer1.0-plugins-good
Requires:       gstreamer1.0-plugins-ugly


%description
Mopidy is an extensible music server written in Python.
Mopidy plays music from local disk, Spotify, SoundCloud, Google Play Music, and
more. You edit the playlist from any phone, tablet, or computer using a range
of MPD and web clients.

Vanilla Mopidy only plays music from your local disk and radio streams.
Through extensions, Mopidy can play music from cloud services like Spotify,
SoundCloud, and Google Play Music.

With Mopidy's extension support, backends for new music sources can be easily
added.


%prep
%autosetup -p1 -n %{name}-%{version}%{?prel}

# without this, mopidy must be installed for docs to be able to be built.
# Note: jodal promised to remove the necessity for this hack in a future version
sed -i 's/^__version__ = .*$/__version__ = "%{version}"/' mopidy/__init__.py

%build
%py3_build

make SPHINXBUILD=sphinx-build-3 html man -C docs
rm docs/_build/html/.buildinfo

%install
%py3_install

# mopidyctl
install -Dpm755 extra/mopidyctl/mopidyctl %{buildroot}%{_bindir}/mopidyctl
install -Dpm644 extra/mopidyctl/mopidyctl.8 %{buildroot}%{_mandir}/man8/mopidyctl.8

# man page
install -Dpm644 docs/_build/man/mopidy.1 %{buildroot}%{_mandir}/man1/mopidy.1

# systemd .service
install -Dpm644 extra/systemd/mopidy.service %{buildroot}%{_unitdir}/mopidy.service

# system user home dir
install -dm755 %{buildroot}%{_tmpfilesdir}
cat >> %{buildroot}%{_tmpfilesdir}/%{name}.conf << EOF
d %{_sharedstatedir}/%{name} 0755 mopidy mopidy
EOF

# cache dir
install -dm755 %{buildroot}%{_var}/cache/%{name}

# configs
install -dm755 %{buildroot}%{_sysconfdir}/%{name}
touch %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
install -dm755 %{buildroot}%{_datadir}/%{name}/conf.d
cat >> %{buildroot}%{_datadir}/%{name}/conf.d/%{name}.conf << EOF
# This is the %{_vendor} specific default configuration for Mopidy.
# Your changes should go into /etc/mopidy/mopidy.conf
[core]
cache_dir = /var/cache/mopidy
config_dir = /etc/mopidy
data_dir = /var/lib/mopidy
EOF

%pre
%_pre_useradd mopidy %{_sharedstatedir}/%{name} %{_sbindir}/nologin
%_pre_groupadd mopidy

%post
%_tmpfilescreate mopidy
%systemd_post mopidy.service

%preun
%systemd_preun mopidy.service

%files
%doc docs/_build/html
%{_bindir}/mopidy
%{_mandir}/man1/mopidy.1*
%{_bindir}/mopidyctl
%{_mandir}/man8/mopidyctl.8*
%{_unitdir}/mopidy.service
%{_tmpfilesdir}/%{name}.conf

%attr(-,mopidy,mopidy) %dir %{_var}/cache/%{name}/

%attr(-,mopidy,mopidy) %dir %{_sysconfdir}/%{name}/
%ghost %config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf

%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/conf.d/
%{_datadir}/%{name}/conf.d/%{name}.conf
%{python3_sitelib}/mopidy/
%{python3_sitelib}/Mopidy-%{version}%{?prel}-py%{python3_version}.egg-info


%changelog
* Fri Mar 03 2023 daviddavid <daviddavid> 3.0.2-4.mga9
+ Revision: 1946644
- add patch to fix build with Sphinx >= 6.0

* Mon Feb 28 2022 tv <tv> 3.0.2-3.mga9
+ Revision: 1786784
- Fix filelist for python-3.10
- Rebuild for python-3.10

* Sat Jun 26 2021 tmb <tmb> 3.0.2-2.mga9
+ Revision: 1733563
- rebuild for python 3.9

* Tue Apr 28 2020 daviddavid <daviddavid> 3.0.2-1.mga9
+ Revision: 1572911
- new version: 3.0.2

* Tue Mar 31 2020 wally <wally> 3.0.1-2.mga8
+ Revision: 1562749
- add systemd .service
- build html docs
- install mopidyctl and a man page for it

* Tue Mar 31 2020 wally <wally> 3.0.1-1.mga8
+ Revision: 1562722
- new version 3.0.1
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 2.1.0-2.mga7
+ Revision: 1279953
- Mageia 7 Mass Rebuild

* Thu Jan 04 2018 kekepower <kekepower> 2.1.0-1.mga7
+ Revision: 1190057
- Updated Source0 to use pypi.io instead of github
- Updated to versin 2.1.0
- Now using gstreamer1.0

* Tue Feb 16 2016 philippem <philippem> 2.0.0-1.mga6
+ Revision: 962646
- update to 2.0.0

* Sat Oct 31 2015 philippem <philippem> 1.1.1-1.mga6
+ Revision: 896970
- update to 1.1.1

* Thu Sep 10 2015 philippem <philippem> 1.1.0-1.mga6
+ Revision: 875704
- update to 1.1.0

* Sat Jul 25 2015 philippem <philippem> 1.0.8-1.mga6
+ Revision: 857628
- update to 1.0.8

* Sun Nov 23 2014 philippem <philippem> 0.19.4-3.mga5
+ Revision: 798536
- change group, remove system wide settings

* Mon Nov 03 2014 philippem <philippem> 0.19.4-2.mga5
+ Revision: 795348
- add requires

* Sun Nov 02 2014 philippem <philippem> 0.19.4-1.mga5
+ Revision: 795225
- imported package mopidy

